@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback; # git description: v0.021-3-g911b5aa
+package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback; # git description: v0.022-4-ga01389b
 # ABSTRACT: Generate a Build.PL that uses Module::Build::Tiny, falling back to Module::Build as needed
 # KEYWORDS: plugin installer Module::Build Build.PL toolchain legacy ancient backcompat
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.022';
+our $VERSION = '0.023';
 
 use Moose;
 with
@@ -166,7 +166,7 @@ sub setup_installer
     {
         $self->zilla->prune_file($file);
 
-        $self->log('something else changed the content of the Module::Build::Tiny version of Build.PL -- maybe you should switch back to [ModuleBuildTiny]?')
+        $self->log([ 'something else changed the content of the Module::Build::Tiny version of Build.PL -- maybe you should switch back to [ModuleBuildTiny]? (%s)', $file->added_by ])
             if $file->content ne $files{'Dist::Zilla::Plugin::ModuleBuildTiny'}{content};
     }
 
@@ -387,7 +387,7 @@ Dist::Zilla::Plugin::ModuleBuildTiny::Fallback - Generate a Build.PL that uses M
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -505,7 +505,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-irc://irc.perl.org/#distzilla.
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
